# Checklist

Note: If any of the items in the checklist are not relevant to your PR, just check the box.

## For any Pull Request

Is the following correct:
* [ ] the title of the Pull Request?
* [ ] the title of the corresponding issue?
* [ ] there are no other open [Pull Requests](../../../../pulls) for the same update/change? <!-- markdown-link-check-disable-line -->
* [ ] that the issue which this Pull Request fixes ("Fixes...") is mentioned?

## When Changes Were Made

Did you:
* [ ] update the changelog?
* [ ] update the implementation?
* [ ] check coverage and add tests: unit tests and, if relevant, integration tests?
* [ ] update the User Guide & other documentation?
* [ ] resolve any failing CI criteria (incl. Sonar quality gate)?

## When Preparing a Release

Have you:
* [ ] thought about version number (major, minor, patch)?
* [ ] checked Exasol packages for updates and resolved open vulnerabilities, if easily possible?
  * [ ] executed `poetry run -- tbx workflow update`?
